@@ -116,6 +116,11 @@ class AssertStateABC(metaclass=ABCMeta):
         interface.set_assert_timer(pim_globals.ASSERT_TIME)
         interface.send_assert()
 
+    @staticmethod
+    @abstractmethod
+    def is_preferred_assert(interface: "TreeInterfaceDownstream", received_metric):
+        raise NotImplementedError()
+
     # Override
     def __str__(self) -> str:
         return "AssertSM:" + self.__class__.__name__
@@ -127,6 +132,10 @@ class NoInfoState(AssertStateABC):
     This router has no (S,G) Assert state on interface I.
     '''
 
+    @staticmethod
+    def is_preferred_assert(interface: "TreeInterfaceDownstream", received_metric):
+        return received_metric.is_better_than(interface._assert_winner_metric)
+
     @staticmethod
     def receivedDataFromDownstreamIf(interface: "TreeInterfaceDownstream"):
         """
@@ -212,6 +221,10 @@ class WinnerState(AssertStateABC):
     interface I.
     '''
 
+    @staticmethod
+    def is_preferred_assert(interface: "TreeInterfaceDownstream", received_metric):
+        return received_metric.is_better_than(interface.my_assert_metric())
+
     @staticmethod
     def receivedDataFromDownstreamIf(interface: "TreeInterfaceDownstream"):
         """
@@ -294,6 +307,11 @@ class LoserState(AssertStateABC):
     forward packets from S destined for G onto interface I.
     '''
 
+    @staticmethod
+    def is_preferred_assert(interface: "TreeInterfaceDownstream", received_metric):
+        return received_metric.is_better_than(interface._assert_winner_metric) or \
+               received_metric.equal_metric(interface._assert_winner_metric)
+
     @staticmethod
     def receivedDataFromDownstreamIf(interface: "TreeInterfaceDownstream"):
         """
